@@ -13,7 +13,7 @@ void ffPrintUsers(FFUsersOptions* options)
 {
     FF_LIST_AUTO_DESTROY users = ffListCreate(sizeof(FFUserResult));
 
-    const char* error = ffDetectUsers(&users);
+    const char* error = ffDetectUsers(options, &users);
 
     if(error)
     {
@@ -69,11 +69,11 @@ void ffPrintUsers(FFUsersOptions* options)
             FFUserResult* user = (FFUserResult*)ffListGet(&users, i);
 
             FF_PRINT_FORMAT_CHECKED(FF_USERS_MODULE_NAME, users.length == 1 ? 0 : (uint8_t) (i + 1), &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_USERS_NUM_FORMAT_ARGS, ((FFformatarg[]){
-                {FF_FORMAT_ARG_TYPE_STRBUF, &user->name},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &user->hostName},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &user->sessionName},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &user->clientIp},
-                {FF_FORMAT_ARG_TYPE_STRING, ffTimeToShortStr(user->loginTime)},
+                {FF_FORMAT_ARG_TYPE_STRBUF, &user->name, "name"},
+                {FF_FORMAT_ARG_TYPE_STRBUF, &user->hostName, "host-name"},
+                {FF_FORMAT_ARG_TYPE_STRBUF, &user->sessionName, "session-name"},
+                {FF_FORMAT_ARG_TYPE_STRBUF, &user->clientIp, "client-ip"},
+                {FF_FORMAT_ARG_TYPE_STRING, ffTimeToShortStr(user->loginTime), "login-time"},
             }));
         }
     }
@@ -94,12 +94,18 @@ bool ffParseUsersCommandOptions(FFUsersOptions* options, const char* key, const
     if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
         return true;
 
-    if(ffStrEqualsIgnCase(subKey, "compact"))
+    if (ffStrEqualsIgnCase(subKey, "compact"))
     {
         options->compact = ffOptionParseBoolean(value);
         return true;
     }
 
+    if (ffStrEqualsIgnCase(subKey, "myself-only"))
+    {
+        options->myselfOnly = ffOptionParseBoolean(value);
+        return true;
+    }
+
     return false;
 }
 
@@ -110,7 +116,7 @@ void ffParseUsersJsonObject(FFUsersOptions* options, yyjson_val* module)
     yyjson_obj_foreach(module, idx, max, key_, val)
     {
         const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type"))
+        if (ffStrEqualsIgnCase(key, "type"))
             continue;
 
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
@@ -122,6 +128,12 @@ void ffParseUsersJsonObject(FFUsersOptions* options, yyjson_val* module)
             continue;
         }
 
+        if (ffStrEqualsIgnCase(key, "myselfOnly"))
+        {
+            options->myselfOnly = yyjson_get_bool(val);
+            continue;
+        }
+
         ffPrintError(FF_USERS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
     }
 }
@@ -135,13 +147,16 @@ void ffGenerateUsersJsonConfig(FFUsersOptions* options, yyjson_mut_doc* doc, yyj
 
     if (options->compact != defaultOptions.compact)
         yyjson_mut_obj_add_bool(doc, module, "compact", options->compact);
+
+    if (options->myselfOnly != defaultOptions.myselfOnly)
+        yyjson_mut_obj_add_bool(doc, module, "myselfOnly", options->myselfOnly);
 }
 
-void ffGenerateUsersJsonResult(FF_MAYBE_UNUSED FFUsersOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+void ffGenerateUsersJsonResult(FFUsersOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
     FF_LIST_AUTO_DESTROY results = ffListCreate(sizeof(FFUserResult));
 
-    const char* error = ffDetectUsers(&results);
+    const char* error = ffDetectUsers(options, &results);
 
     if(error)
     {
@@ -176,11 +191,11 @@ void ffGenerateUsersJsonResult(FF_MAYBE_UNUSED FFUsersOptions* options, yyjson_m
 void ffPrintUsersHelpFormat(void)
 {
     FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_USERS_MODULE_NAME, "{1}@{2} - login time {5}", FF_USERS_NUM_FORMAT_ARGS, ((const char* []) {
-        "User name",
-        "Host name",
-        "Session name",
-        "Client IP",
-        "Login Time in local timezone"
+        "User name - user-name",
+        "Host name - host-name",
+        "Session name - session",
+        "Client IP - client-ip",
+        "Login Time in local timezone - login-time",
     }));
 }
 
@@ -197,9 +212,10 @@ void ffInitUsersOptions(FFUsersOptions* options)
         ffPrintUsersHelpFormat,
         ffGenerateUsersJsonConfig
     );
-    ffOptionInitModuleArg(&options->moduleArgs);
+    ffOptionInitModuleArg(&options->moduleArgs, "");
 
     options->compact = false;
+    options->myselfOnly = false;
 }
 
 void ffDestroyUsersOptions(FFUsersOptions* options)
